@@ -22,12 +22,12 @@
 //   Inc. ,51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 //
 
-#include <kmenubar.h>
+#include <tdemenubar.h>
 
 class KVILIB_API KviTalMenuBar : public KMenuBar
 {
 	Q_OBJECT
-  TQ_OBJECT
+  
 public:
 	KviTalMenuBar(TQWidget * par,const char * nam);
 	~KviTalMenuBar();
