@@ -153,7 +153,7 @@ TQPixmap                             * g_pActivityMeterPixmap    = 0;
 
 #ifdef COMPILE_PSEUDO_TRANSPARENCY
 
-	#ifdef COMPILE_KDE_SUPPORT
+	#ifdef COMPILE_TDE_SUPPORT
 		#include <ksharedpixmap.h>
 		#include <netwm.h>
 		#include <kimageeffect.h>
@@ -161,7 +161,7 @@ TQPixmap                             * g_pActivityMeterPixmap    = 0;
 		#include <tqdatastream.h>
 		#include <tqcstring.h>
 
-		KSharedPixmap         * g_pKdeDesktopBackground             = 0; // the shared pixmap that we get from KWin
+		TDESharedPixmap         * g_pKdeDesktopBackground             = 0; // the shared pixmap that we get from KWin
 	#endif
 
 	#include <tqimage.h>
@@ -1091,7 +1091,7 @@ void KviApp::fileDownloadTerminated(bool bSuccess,const TQString &szRemoteUrl,co
 
 #ifdef COMPILE_PSEUDO_TRANSPARENCY
 
-	#ifdef COMPILE_KDE_SUPPORT
+	#ifdef COMPILE_TDE_SUPPORT
 
         #include <netwm.h>
 
@@ -1111,15 +1111,15 @@ void KviApp::fileDownloadTerminated(bool bSuccess,const TQString &szRemoteUrl,co
 	#warning "The following warning will disappear soon..."
 			// FIXME: this form should be used starting from KDE 3.2
 			unsigned long l = NET::CurrentDesktop;
-			NETRootInfo rinfo( qt_xdisplay(), &l ,1 ,-1,true);
+			NETRootInfo rinfo( tqt_xdisplay(), &l ,1 ,-1,true);
 #else
-			NETRootInfo rinfo(qt_xdisplay(),NET::CurrentDesktop);
+			NETRootInfo rinfo(tqt_xdisplay(),NET::CurrentDesktop);
 #endif
 			rinfo.activate();
 
 		    TQString name = TQString("DESKTOP%1").arg(rinfo.currentDesktop());
 
-			g_pKdeDesktopBackground = new KSharedPixmap();
+			g_pKdeDesktopBackground = new TDESharedPixmap();
 			connect(g_pKdeDesktopBackground,TQT_SIGNAL(done(bool)),this,TQT_SLOT(kdeRootPixmapDownloadComplete(bool)));
 
 		    if(!(g_pKdeDesktopBackground->isAvailable(name)))
@@ -1151,11 +1151,11 @@ void KviApp::fileDownloadTerminated(bool bSuccess,const TQString &szRemoteUrl,co
 			//}
 		}
 
-	#endif //COMPILE_KDE_SUPPORT
+	#endif //COMPILE_TDE_SUPPORT
 
 	void KviApp::destroyPseudoTransparency()
 	{
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_TDE_SUPPORT
 		if(g_pKdeDesktopBackground)
 		{
 			delete g_pKdeDesktopBackground;
@@ -1163,7 +1163,7 @@ void KviApp::fileDownloadTerminated(bool bSuccess,const TQString &szRemoteUrl,co
 		}
 		// forget the backgroundChanged signal (will do nothing if it is not connected)
 		disconnect(this,TQT_SIGNAL(backgroundChanged(int)),this,TQT_SLOT(kdeRootPixmapChanged(int)));
-#endif //COMPILE_KDE_SUPPORT
+#endif //COMPILE_TDE_SUPPORT
 		if(g_pShadedParentGlobalDesktopBackground)
 		{
 			delete g_pShadedParentGlobalDesktopBackground;
@@ -1183,11 +1183,11 @@ void KviApp::fileDownloadTerminated(bool bSuccess,const TQString &szRemoteUrl,co
 		TQTimer::singleShot(0,this,TQT_SLOT(updatePseudoTransparency()));
 	}
 
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_TDE_SUPPORT
 
 	#define kimageeffect_fade KImageEffect::fade
 
-#else //!COMPILE_KDE_SUPPORT
+#else //!COMPILE_TDE_SUPPORT
 
 	//
 	// This function is taken from the KDE kimageeffect.cpp
@@ -1252,7 +1252,7 @@ void KviApp::fileDownloadTerminated(bool bSuccess,const TQString &szRemoteUrl,co
 		return img;
 	}
 
-#endif //!COMPILE_KDE_SUPPORT
+#endif //!COMPILE_TDE_SUPPORT
 
 	void KviApp::createGlobalBackgrounds(TQPixmap * pix)
 	{
@@ -1287,9 +1287,9 @@ void KviApp::fileDownloadTerminated(bool bSuccess,const TQString &szRemoteUrl,co
 void KviApp::kdeRootPixmapChanged(int iDesktop)
 {
 #ifdef COMPILE_PSEUDO_TRANSPARENCY
-	#ifdef COMPILE_KDE_SUPPORT
+	#ifdef COMPILE_TDE_SUPPORT
 		if(!KVI_OPTION_BOOL(KviOption_boolUpdateKdeBackgroundOnChange))return;
-		NETRootInfo rinfo(qt_xdisplay(),NET::CurrentDesktop);
+		NETRootInfo rinfo(tqt_xdisplay(),NET::CurrentDesktop);
 		rinfo.activate();
 		if(iDesktop == rinfo.currentDesktop())
 			updatePseudoTransparency();
@@ -1300,7 +1300,7 @@ void KviApp::kdeRootPixmapChanged(int iDesktop)
 void KviApp::kdeRootPixmapDownloadComplete(bool bSuccess)
 {
 #ifdef COMPILE_PSEUDO_TRANSPARENCY
-	#ifdef COMPILE_KDE_SUPPORT
+	#ifdef COMPILE_TDE_SUPPORT
 		if(!bSuccess)
 		{
 			debug("Failed to download the KDE root background image...");
@@ -1315,7 +1315,7 @@ void KviApp::kdeRootPixmapDownloadComplete(bool bSuccess)
 		}
 		delete g_pKdeDesktopBackground;
 		g_pKdeDesktopBackground = 0;
-	#endif //COMPILE_KDE_SUPPORT
+	#endif //COMPILE_TDE_SUPPORT
 #endif //COMPILE_PSEUDO_TRANSPARENCY
 }
 
@@ -1326,12 +1326,12 @@ void KviApp::updatePseudoTransparency()
 	m_bUpdatePseudoTransparencyPending = false;
 	if(KVI_OPTION_BOOL(KviOption_boolUseGlobalPseudoTransparency))
 	{
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_TDE_SUPPORT
 		if(KVI_OPTION_BOOL(KviOption_boolObtainGlobalBackgroundFromKde))
 		{
 			downloadKdeRootPixmap();
 		} else {
-#endif //COMPILE_KDE_SUPPORT
+#endif //COMPILE_TDE_SUPPORT
 			if(KVI_OPTION_PIXMAP(KviOption_pixmapGlobalTransparencyBackground).pixmap())
 			{
 				createGlobalBackgrounds(KVI_OPTION_PIXMAP(KviOption_pixmapGlobalTransparencyBackground).pixmap());
@@ -1339,9 +1339,9 @@ void KviApp::updatePseudoTransparency()
 				destroyPseudoTransparency();
 				KVI_OPTION_BOOL(KviOption_boolUseGlobalPseudoTransparency) = false;
 			}
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_TDE_SUPPORT
 		}
-#endif //COMPILE_KDE_SUPPORT
+#endif //COMPILE_TDE_SUPPORT
 	} else {
 		destroyPseudoTransparency();
 		if(g_pFrame)g_pFrame->updatePseudoTransparency();
